@@ -3,6 +3,7 @@ __all__ = ['thread',
            'process',
            'process_pool',
            'synchronized',
+           'sighandler',
            'Task',
            'ThreadPool',
            'PebbleError',
@@ -13,6 +14,6 @@ __all__ = ['thread',
 from .pebble import PebbleError, TaskCancelled, TimeoutError, Task
 from .pools.process import ProcessPool
 from .pools.thread import ThreadPool
-from .decorators.generic import synchronized
+from .decorators.generic import synchronized, sighandler
 from .decorators.thread import thread, thread_pool
 from .decorators.process import process, process_pool
